@@ -1,6 +1,6 @@
 package Keyword::With;
 # ABSTRACT: provide new syntax to use a 'given' statement without an experimental warning
-$Keyword::With::VERSION = '0.002';
+$Keyword::With::VERSION = '0.003';
 use strict;
 use warnings;
 
@@ -27,11 +27,11 @@ Keyword::With - provide new syntax to use a 'given' statement without an experim
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 DESCRIPTION
 
-Provide a construct almost identical to given (...) { } that evaluates an list expression in scalar context (assigning it to $_) then executing a block of code. 
+Provide a construct almost identical to `given (...) { }` that evaluates an list expression in scalar context (assigning it to `$_`) then executing a block of code. 
 
 =head1 NAME 
 
@@ -48,8 +48,8 @@ Keyword::With
 or 
 
  with ( some_func() ) {
-    print "matches\n" if grep { m/$_/ } qr/abc/, qr/def/;
-    print "does not match\n"; 
+     print "matches\n" if grep { m/$_/ } qr/abc/, qr/def/;
+     print "does not match\n"; 
  } 
 
 =head1 ADVANTAGES 
@@ -58,7 +58,13 @@ No experimental warning
 
 =head1 DISADVANTAGES 
 
-Cannot use builtins that modify $_ with with blocks because they will clobber the $_ value set by with (...) { }. This was already a disadvantage of given blocks. 
+Cannot use builtins that modify `$_` with with blocks because they will clobber the `$_` value set by `with (...) { }`. This was already a disadvantage of given blocks. A reasonable approach would be to create a new lexical variable within the `with` block:
+
+ with ( [qw(1 2 3 5 8 13 21)] ) {
+     my @first_7_fibs = @$_;
+     my @new_first_7_fibs = map { $_ + 1 } @first_7_fibs;
+     ...
+ }
 
 =head1 AUTHOR
 
